@@ -20,13 +20,8 @@
 
 #include "databasetestdata.h"
 
-#include "musicaudiotrack.h"
-
 #include <QObject>
 #include <QHash>
-#include <QVector>
-#include <QUrl>
-#include <QString>
 
 class MediaPlayListTest : public QObject, public DatabaseTestData
 {
@@ -49,99 +44,45 @@ private Q_SLOTS:
 
     void enqueueArtistCase();
 
+    void enqueueTrackByUrl();
+
+    void enqueueTracksByUrl();
+
+    void enqueueFiles();
+
+    void enqueueSampleFiles();
+
+    void enqueueEmpty();
+
     void removeFirstTrackOfAlbum();
 
+    void testTrackBeenRemoved();
+
+    void testSetData();
+
     void testHasHeader();
 
-    void testHasHeaderWithRestore();
-
     void testHasHeaderWithRemove();
 
+    void testHasHeaderWithRestore();
+
     void testHasHeaderMoveFirst();
 
     void testHasHeaderMoveAnother();
 
-    void testHasHeaderMoveFirstLikeQml();
-
-    void testHasHeaderMoveAnotherLikeQml();
-
-    void testHasHeaderYetAnotherMoveLikeQml();
-
-    void enqueueReplaceAndPlay();
-
-    void crashOnEnqueue();
-
     void restoreMultipleIdenticalTracks();
 
     void restoreTrackWithoutAlbum();
 
     void testHasHeaderAlbumWithSameTitle();
 
-    void testSavePersistentState();
+    void testHasHeaderMoveFirstLikeQml();
 
-    void testReplaceAndPlayArtist();
+    void testHasHeaderMoveAnotherLikeQml();
 
-    void testReplaceAndPlayTrackId();
+    void testHasHeaderYetAnotherMoveLikeQml();
 
-    void testSetData();
-
-    void testRemoveSelection();
-
-    void testTrackBeenRemoved();
-
-    void testBringUpCase();
-
-    void testBringUpCaseFromNewAlbum();
-
-    void testBringUpAndDownCase();
-
-    void testBringUpAndRemoveCase();
-
-    void testBringUpAndRemoveMultipleCase();
-
-    void testBringUpAndRemoveMultipleNotBeginCase();
-
-    void testBringUpAndPlayCase();
-
-    void testBringUpAndSkipNextCase();
-
-    void testBringUpAndSkipPreviousCase();
-
-    void testBringUpAndSkipPreviousAndContinueCase();
-
-    void finishPlayList();
-
-    void randomPlayList();
-
-    void randomAndContinuePlayList();
-
-    void continuePlayList();
-
-    void testRestoreSettings();
-
-    void removeBeforeCurrentTrack();
-
-    void switchToTrackTest();
-
-    void singleTrack();
-
-    void testBringUpAndRemoveLastCase();
-
-    void testSaveAndRestoreSettings();
-
-    void testSaveLoadPlayList();
-
-    void testEnqueueFiles();
-
-    void testEnqueueSampleFiles();
-
-    void testEmptyEnqueue();
-
-    void clearPlayListCase();
-
-    void undoClearPlayListCase();
-
-    void undoReplacePlayListCase();
+    void crashOnEnqueue();
 
 };
 
