@@ -20,6 +20,8 @@
 #ifndef ANDROIDMUSICLISTENER_H
 #define ANDROIDMUSICLISTENER_H
 
+#include "datatypes.h"
+
 #include <QObject>
 #include <QList>
 #include <QHash>
@@ -29,7 +31,6 @@
 #include <memory>
 
 class DatabaseInterface;
-class MusicAudioTrack;
 class AndroidMusicListenerPrivate;
 
 class AndroidMusicListener : public QObject
@@ -76,12 +77,10 @@ Q_SIGNALS:
 
     void clearDatabase(const QString &listenerName);
 
-    void tracksList(const QList<MusicAudioTrack> &tracks, const QHash<QString, QUrl> &covers, const QString &musicSource);
+    void tracksList(const DataTypes::ListTrackDataType &tracks, const QHash<QString, QUrl> &covers);
 
     void removedTracksList(const QList<QUrl> &removedTracks);
 
-    void modifyTracksList(const QList<MusicAudioTrack> &modifiedTracks, const QHash<QString, QUrl> &covers, const QString &musicSource);
-
     void askRestoredTracks(const QString &musicSource);
 
 public Q_SLOTS:
@@ -92,7 +91,7 @@ public Q_SLOTS:
 
     void quitListener();
 
-    void restoredTracks(const QString &musicSource, QHash<QUrl, QDateTime> allFiles);
+    void restoredTracks(QHash<QUrl, QDateTime> allFiles);
 
     void init();
 
