@@ -73,11 +73,6 @@ class ELISALIB_EXPORT AudioWrapper : public QObject
                READ seekable
                NOTIFY seekableChanged)
 
-    Q_PROPERTY(QAudio::Role audioRole
-               READ audioRole
-               WRITE setAudioRole
-               NOTIFY audioRoleChanged)
-
 public:
 
     explicit AudioWrapper(QObject *parent = nullptr);
@@ -102,8 +97,6 @@ public:
 
     bool seekable() const;
 
-    QAudio::Role audioRole() const;
-
 Q_SIGNALS:
 
     void mutedChanged(bool muted);
@@ -122,6 +115,8 @@ Q_SIGNALS:
 
     void positionChanged(qint64 position);
 
+    void currentPlayingForRadiosChanged(const QString &title, const QString &nowPlaying);
+
     void seekableChanged(bool seekable);
 
     void playing();
@@ -130,8 +125,6 @@ Q_SIGNALS:
 
     void stopped();
 
-    void audioRoleChanged();
-
 public Q_SLOTS:
 
     void setMuted(bool muted);
@@ -154,8 +147,6 @@ public Q_SLOTS:
 
     void seek(qint64 position);
 
-    void setAudioRole(QAudio::Role audioRole);
-
 private Q_SLOTS:
 
     void mediaStatusChanged();
