@@ -33,10 +33,12 @@ class QIcon;
 class QAction;
 class MusicListenersManager;
 class MediaPlayList;
+class MediaPlayListProxyModel;
 class AudioWrapper;
 class ManageAudioPlayer;
 class ManageMediaPlayerControl;
 class ManageHeaderBar;
+class QQmlApplicationEngine;
 class ElisaApplicationPrivate;
 
 class ELISALIB_EXPORT ElisaApplication : public QObject
@@ -57,6 +59,12 @@ class ELISALIB_EXPORT ElisaApplication : public QObject
                READ mediaPlayList
                NOTIFY mediaPlayListChanged)
 
+
+    Q_PROPERTY(MediaPlayListProxyModel *mediaPlayListProxyModel
+               READ mediaPlayListProxyModel
+               NOTIFY mediaPlayListProxyModelChanged)
+
+
     Q_PROPERTY(AudioWrapper *audioPlayer
                READ audioPlayer
                NOTIFY audioPlayerChanged)
@@ -73,6 +81,14 @@ class ELISALIB_EXPORT ElisaApplication : public QObject
                READ manageHeaderBar
                NOTIFY manageHeaderBarChanged)
 
+    Q_PROPERTY(bool showProgressOnTaskBar
+               READ showProgressOnTaskBar
+               NOTIFY showProgressOnTaskBarChanged)
+
+    Q_PROPERTY(bool showSystemTrayIcon
+               READ showSystemTrayIcon
+               NOTIFY showSystemTrayIconChanged)
+
 public:
     explicit ElisaApplication(QObject *parent = nullptr);
 
@@ -92,6 +108,8 @@ public:
 
     MediaPlayList *mediaPlayList() const;
 
+    MediaPlayListProxyModel *mediaPlayListProxyModel() const;
+
     AudioWrapper *audioPlayer() const;
 
     ManageAudioPlayer *audioControl() const;
@@ -100,6 +118,10 @@ public:
 
     ManageHeaderBar *manageHeaderBar() const;
 
+    bool showProgressOnTaskBar() const;
+
+    bool showSystemTrayIcon() const;
+
 Q_SIGNALS:
 
     void argumentsChanged();
@@ -108,6 +130,8 @@ Q_SIGNALS:
 
     void mediaPlayListChanged();
 
+    void mediaPlayListProxyModelChanged();
+
     void audioPlayerChanged();
 
     void audioControlChanged();
@@ -123,6 +147,10 @@ Q_SIGNALS:
 
     void initializationDone();
 
+    void showProgressOnTaskBarChanged();
+
+    void showSystemTrayIconChanged();
+
 public Q_SLOTS:
 
     void appHelpActivated();
@@ -145,6 +173,10 @@ public Q_SLOTS:
 
     void initialize();
 
+public:
+
+    void setQmlEngine(QQmlApplicationEngine *engine);
+
 private Q_SLOTS:
 
     void goBack();
@@ -159,6 +191,8 @@ private Q_SLOTS:
 
     void playPause();
 
+    void configChanged();
+
 private:
 
     void initializeModels();
