@@ -19,10 +19,12 @@
 #include "filebrowserproxymodel.h"
 
 #include "filebrowsermodel.h"
+#include "mediaplaylistproxymodel.h"
 
 #include <QReadLocker>
-#include <QtConcurrentRun>
 #include <QDir>
+#include <QtConcurrent>
+
 #include <KIOWidgets/KDirLister>
 #include "elisautils.h"
 
@@ -93,7 +95,7 @@ void FileBrowserProxyModel::enqueueToPlayList()
         for (int rowIndex = 0, maxRowCount = rowCount(); rowIndex < maxRowCount; ++rowIndex) {
             auto currentIndex = index(rowIndex, 0);
             if (!data(currentIndex, FileBrowserModel::IsDirectoryRole).toBool()) {
-                allTrackUrls.push_back({0, {}, data(currentIndex, FileBrowserModel::FileUrlRole).toUrl()});
+                allTrackUrls.push_back({{}, {}, data(currentIndex, FileBrowserModel::FileUrlRole).toUrl()});
             }
         }
         Q_EMIT filesToEnqueue(allTrackUrls,
@@ -111,7 +113,7 @@ void FileBrowserProxyModel::replaceAndPlayOfPlayList()
         for (int rowIndex = 0, maxRowCount = rowCount(); rowIndex < maxRowCount; ++rowIndex) {
             auto currentIndex = index(rowIndex, 0);
             if (!data(currentIndex, FileBrowserModel::IsDirectoryRole).toBool()) {
-                allTrackUrls.push_back({0, {}, data(currentIndex, FileBrowserModel::FileUrlRole).toUrl()});
+                allTrackUrls.push_back({{}, {}, data(currentIndex, FileBrowserModel::FileUrlRole).toUrl()});
             }
         }
         Q_EMIT filesToEnqueue(allTrackUrls,
@@ -138,6 +140,22 @@ QString FileBrowserProxyModel::parentFolder() const
     }
 }
 
+void FileBrowserProxyModel::disconnectPlayList()
+{
+    if (mPlayList) {
+        disconnect(this, &FileBrowserProxyModel::filesToEnqueue,
+                   mPlayList, static_cast<void(MediaPlayListProxyModel::*)(const ElisaUtils::EntryDataList&, ElisaUtils::PlayListEntryType, ElisaUtils::PlayListEnqueueMode, ElisaUtils::PlayListEnqueueTriggerPlay)>(&MediaPlayListProxyModel::enqueue));
+    }
+}
+
+void FileBrowserProxyModel::connectPlayList()
+{
+    if (mPlayList) {
+        connect(this, &FileBrowserProxyModel::filesToEnqueue,
+                mPlayList, static_cast<void(MediaPlayListProxyModel::*)(const ElisaUtils::EntryDataList&, ElisaUtils::PlayListEntryType, ElisaUtils::PlayListEnqueueMode, ElisaUtils::PlayListEnqueueTriggerPlay)>(&MediaPlayListProxyModel::enqueue));
+    }
+}
+
 void FileBrowserProxyModel::openParentFolder()
 {
     auto fileBrowserModel = dynamic_cast<FileBrowserModel*>(sourceModel());
@@ -216,10 +234,29 @@ void FileBrowserProxyModel::setSourceModel(QAbstractItemModel *sourceModel)
     openFolder(mTopFolder, true);
 }
 
+MediaPlayListProxyModel *FileBrowserProxyModel::playList() const
+{
+    return mPlayList;
+}
+
 void FileBrowserProxyModel::sortModel(Qt::SortOrder order)
 {
     this->sort(0,order);
     Q_EMIT sortedAscendingChanged();
 }
 
+void FileBrowserProxyModel::setPlayList(MediaPlayListProxyModel *playList)
+{
+    disconnectPlayList();
+
+    if (mPlayList == playList) {
+        return;
+    }
+
+    mPlayList = playList;
+    Q_EMIT playListChanged();
+
+    connectPlayList();
+}
+
 #include "moc_filebrowserproxymodel.cpp"
