@@ -24,13 +24,16 @@
 #include "filescanner.h"
 #include "elisautils.h"
 
-#include <KIOFileWidgets/KDirSortFilterProxyModel>
+#include <KDirSortFilterProxyModel>
+
 #include <QRegularExpression>
 #include <QReadWriteLock>
 #include <QThreadPool>
 
 #include <memory>
 
+class MediaPlayListProxyModel;
+
 class ELISALIB_EXPORT FileBrowserProxyModel : public KDirSortFilterProxyModel
 {
     Q_OBJECT
@@ -52,6 +55,8 @@ class ELISALIB_EXPORT FileBrowserProxyModel : public KDirSortFilterProxyModel
                READ sortedAscending
                NOTIFY sortedAscendingChanged)
 
+    Q_PROPERTY(MediaPlayListProxyModel* playList READ playList WRITE setPlayList NOTIFY playListChanged)
+
 public:
 
     explicit FileBrowserProxyModel(QObject *parent = nullptr);
@@ -68,6 +73,8 @@ public:
 
     void setSourceModel(QAbstractItemModel *sourceModel) override;
 
+    MediaPlayListProxyModel* playList() const;
+
 public Q_SLOTS:
 
     void enqueueToPlayList();
@@ -82,6 +89,8 @@ public Q_SLOTS:
 
     void sortModel(Qt::SortOrder order);
 
+    void setPlayList(MediaPlayListProxyModel* playList);
+
 Q_SIGNALS:
 
     void filesToEnqueue(const ElisaUtils::EntryDataList &newFiles,
@@ -97,6 +106,8 @@ Q_SIGNALS:
 
     void sortedAscendingChanged();
 
+    void playListChanged();
+
 protected:
 
     bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
@@ -105,6 +116,10 @@ private:
 
     QString parentFolder() const;
 
+    void disconnectPlayList();
+
+    void connectPlayList();
+
     QString mTopFolder;
 
     FileScanner mFileScanner;
@@ -117,6 +132,8 @@ private:
 
     QThreadPool mThreadPool;
 
+    MediaPlayListProxyModel* mPlayList = nullptr;
+
 };
 
 #endif // FILEBROWSERPROXYMODEL_H
