@@ -26,11 +26,9 @@
 
 #include <QDBusAbstractAdaptor>
 #include <QDBusObjectPath>
-#include <QPointer>
-#include <QUrl>
 #include <QDBusMessage>
 
-class MediaPlayList;
+class MediaPlayListProxyModel;
 class ManageAudioPlayer;
 class ManageMediaPlayerControl;
 class ManageHeaderBar;
@@ -39,7 +37,7 @@ class AudioWrapper;
 class ELISALIB_EXPORT MediaPlayer2Player : public QDBusAbstractAdaptor
 {
     Q_OBJECT
-    Q_CLASSINFO("D-Bus Interface", "org.mpris.MediaPlayer2.Player") // Docs: http://specifications.freedesktop.org/mpris-spec/latest/Player_Interface.html
+    Q_CLASSINFO("D-Bus Interface", "org.mpris.MediaPlayer2.Player") // Docs: https://specifications.freedesktop.org/mpris-spec/latest/Player_Interface.html
 
     Q_PROPERTY(QString PlaybackStatus READ PlaybackStatus NOTIFY playbackStatusChanged)
     Q_PROPERTY(double Rate READ Rate WRITE setRate NOTIFY rateChanged)
@@ -58,11 +56,12 @@ class ELISALIB_EXPORT MediaPlayer2Player : public QDBusAbstractAdaptor
     Q_PROPERTY(int mediaPlayerPresent READ mediaPlayerPresent WRITE setMediaPlayerPresent NOTIFY mediaPlayerPresentChanged)
 
 public:
-    explicit MediaPlayer2Player(MediaPlayList *playListControler,
+    explicit MediaPlayer2Player(MediaPlayListProxyModel *playListControler,
                                 ManageAudioPlayer *manageAudioPlayer,
                                 ManageMediaPlayerControl* manageMediaPlayerControl,
                                 ManageHeaderBar * manageHeaderBar,
                                 AudioWrapper *audioPlayer,
+                                bool showProgressOnTaskBar,
                                 QObject* parent = nullptr);
     ~MediaPlayer2Player() override;
 
@@ -82,6 +81,9 @@ public:
     int currentTrack() const;
     int mediaPlayerPresent() const;
 
+    bool showProgressOnTaskBar() const;
+    void setShowProgressOnTaskBar(bool value);
+
 Q_SIGNALS:
     void Seeked(qlonglong Position);
 
@@ -156,13 +158,15 @@ private:
     bool m_canGoNext = false;
     bool m_canGoPrevious = false;
     qlonglong m_position = 0;
-    MediaPlayList *m_playListControler = nullptr;
+    MediaPlayListProxyModel *m_playListControler = nullptr;
     bool m_playerIsSeekableChanged = false;
     ManageAudioPlayer* m_manageAudioPlayer = nullptr;
     ManageMediaPlayerControl* m_manageMediaPlayerControl = nullptr;
     ManageHeaderBar * m_manageHeaderBar = nullptr;
     AudioWrapper *m_audioPlayer = nullptr;
     mutable QDBusMessage mProgressIndicatorSignal;
+    int mPreviousProgressPosition = 0;
+    bool mShowProgressOnTaskBar = true;
 };
 
 #endif // MEDIAPLAYER2PLAYER_H
