@@ -74,10 +74,14 @@ public Q_SLOTS:
     void newUrlInList(const QUrl &entryUrl,
                       ElisaUtils::PlayListEntryType databaseIdType);
 
+    void updateSingleFileMetaData(const QUrl &url, DataTypes::ColumnsRoles role, QVariant data);
+
 private:
 
     void newArtistInList(qulonglong newDatabaseId, const QString &artist);
 
+    void newGenreInList(qulonglong newDatabaseId, const QString &entryTitle);
+
     void newAlbumInList(qulonglong newDatabaseId,
                         const QString &entryTitle);
 
